===================================================
``psyclone.psyad.transformations.assignment_trans``
===================================================

.. automodule:: psyclone.psyad.transformations.assignment_trans

   .. contents::
      :local:

.. currentmodule:: psyclone.psyad.transformations.assignment_trans


Classes
=======

- :py:class:`AssignmentTrans`:
  Implements a transformation to translate a Tangent-Linear


.. autoclass:: AssignmentTrans
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: AssignmentTrans
      :parts: 1
